checkBin: Checks if the specified undiscretized value is included in...

Description Usage Arguments Value

View source: R/discretization.R

Description

TODO I don't really know what this function is there for and at first glance it looks buggy to me

Usage

1
checkBin(value, bin, binIndex)

Arguments

value

the undiscretized value

bin

the discretization options

binIndex

the bin index in the list

Value

True, if value lies within specified discretization option


viadee/anchorsOnR documentation built on Nov. 22, 2019, 5:24 p.m.