Description Usage Arguments Value
View source: R/discretization.R
TODO I don't really know what this function is there for and at first glance it looks buggy to me
1 | checkBin(value, bin, binIndex)
|
value |
the undiscretized value |
bin |
the discretization options |
binIndex |
the bin index in the list |
True, if value lies within specified discretization option
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.